#!/bin/bash 
echo 
echo "--- `date "+%a %Hh%M"`: $0 ----------------------------------------------------------------------"
. ./000_setenv.sh

# first instantiate the deadlines, then load the envir variables via the ./00_setenv.sh
export NOW=$(($(date -u +%s)*1000))         # The current time in POSIX milliseconds.
export HOUR=$((60*60*1000))                 # One hour, in POSIX milliseconds.
export QUARTER=$((15*60*1000))              # One hour, in POSIX milliseconds.
export MINUTE=$((60*1000))              # One hour, in POSIX milliseconds.


#export PAYMENT_DEADLINE=$((NOW+10*HOUR)) 
#export COMPLAINT_DEADLINE=$((NOW+12*HOUR)) 
#export DISPUTE_DEADLINE=$((NOW+14*HOUR)) 
#export MEDIATION_DEADLINE=$((NOW+16*HOUR)) 

# short deadline!
export PAYMENT_DEADLINE=$((NOW+QUARTER)) 
export COMPLAINT_DEADLINE=$((NOW+QUARTER+MINUTE)) 
export DISPUTE_DEADLINE=$((NOW+QUARTER+2*MINUTE)) 
export MEDIATION_DEADLINE=$((NOW+QUARTER+3*MINUTE))

marlowe-cli template escrow --minimum-ada "$INITIAL_LOVELACE"          \
                            --price "$PRICE"                           \
                            --seller "Role=$SELLER_ROLE"               \
                            --buyer "Role=$BUYER_ROLE"                 \
                            --mediator "Role=$MEDIATOR_ROLE"           \
                            --payment-deadline "$PAYMENT_DEADLINE"     \
                            --complaint-deadline "$COMPLAINT_DEADLINE" \
                            --dispute-deadline "$DISPUTE_DEADLINE"     \
                            --mediation-deadline "$MEDIATION_DEADLINE" \
                            --out-contract-file 103_contract.json	\
                            --out-state-file    103_state.json 


# from the contract and state file, produce a marlowe file
marlowe-cli run initialize --roles-currency "$POLICY_ID"     \
                           --contract-file 103_contract.json	 \
                           --state-file    103_state.json     \
                           --out-file      103_marlowe.json   \
                           --print-stats

jq -r '.marloweValidator.address' 103_marlowe.json > contract.address
jq -r '.rolesValidator.address' 103_marlowe.json > payout.address


asnap -t dev mediator.address buyer.address seller.address contract.address payout.address > 103_snap.txt  

# cat <<EOM | millan
# Now is $NOW
# Deadlines:  
#   payment-deadline   $PAYMENT_DEADLINE
#   complaint-deadline $COMPLAINT_DEADLINE
#   dispute-deadline   $DISPUTE_DEADLINE
#   mediation-deadline $MEDIATION_DEADLINE
# EOM
